﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Media;
using System.Windows.Threading;
using System.IO;
using System.Windows.Resources;
using System.Windows.Media.Imaging;


namespace PostCodeManager
{
    public partial class MainPage : PhoneApplicationPage
    {
        #region 成员声明
        Song _playSong; //声明一个Song 类型的变量
        bool _historyItemLaunch;
        const String _playSongKey = "playSong";
        #endregion


        // Constructor
        public MainPage()
        {
            InitializeComponent();
            _playSong = null;
            _historyItemLaunch = false;

            //声明一个Timer 使用线程运行 XNA internals 来自于微软XNA框架
            DispatcherTimer dt = new DispatcherTimer();
            dt.Interval = TimeSpan.FromMilliseconds(33);
            //使用委托调用逐帧调用  FrameworkDispatcher.Update();
            dt.Tick += delegate
            {
                try
                {
                    // 这个函数作用是更新各种XNA组件状态，并触发相应的事件,这个是必须的，否则会报异常
                    FrameworkDispatcher.Update();
                   
                }
                catch  
                {
                    
                    throw;
                }
            };
            dt.Start();

            MediaPlayer.MediaStateChanged += new EventHandler<EventArgs>(MediaPlayer_MediaStateChanged);
           
        }

        /// <summary>
        /// 当页面进入时调用 
        /// </summary>
        /// <param name="e"></param>
        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            MediaLibrary library = new MediaLibrary();
            if (NavigationContext.QueryString.ContainsKey(_playSongKey))
            {
                String songToPlay = NavigationContext.QueryString[_playSongKey];
                foreach (Song song in library.Songs)
                {
                    if (0==String.Compare(songToPlay,song.Name))
                    {
                        _playSong = song;
                    }
                }
                _historyItemLaunch = true;
            }
            else if (MediaPlayer.State==MediaState.Playing)
            {
                _playSong = MediaPlayer.Queue.ActiveSong;
            }
            else
            {
                Random rd = new Random();
                if (library.Songs.Count>0)
                {
                    _playSong = library.Songs[rd.Next(library.Songs.Count)];
                }
                else
                {
                    SongName.Text = "no songs in library";
                    btn_play_music.IsEnabled = false;
                }
            }


            base.OnNavigatedTo(e);
        }

        void MediaPlayer_MediaStateChanged(object sender, EventArgs e)
        {
            switch (MediaPlayer.State)
            {
                
                case MediaState.Playing:
                    btn_play_music.IsEnabled = false;
                    btn_stop.IsEnabled = true;
                    break;
                case MediaState.Paused: 
                case MediaState.Stopped:
                    btn_play_music.IsEnabled = true;
                    btn_stop.IsEnabled = false;
                    break; 
            }
        }

        /// <summary>
        /// 为主窗体添加UI加载完成后的事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void PhoneApplicationPage_Loaded(object sender, RoutedEventArgs e)
        {
            PopulateSongMetaData();
            setInitialButtonState();
            if (_historyItemLaunch)
            {
                playSong();
            }
        }
        

        /// <summary>
        /// 开始播放音乐 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btn_play_music_Click(object sender, RoutedEventArgs e)
        {
            playSong();
        }

        /// <summary>
        /// 停止播放音乐
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btn_stop_Click(object sender, RoutedEventArgs e)
        {
            stopSong();
        }

        /// <summary>
        /// 播放
        /// </summary>
        private void playSong()
        {
            if (_playSong!=null)
            {
                MediaPlayer.Play(_playSong);
            }
        }
        /// <summary>
        /// 停止
        /// </summary>
        private void stopSong()
        {
            if (MediaState.Playing==MediaPlayer.State)
            {
                MediaPlayer.Stop();
            }
        }

        /// <summary>
        /// 使用图片读取图片封面
        /// </summary>
        private void PopulateSongMetaData() 
        {
            if (_playSong!=null)
            {
                SongName.Text = _playSong.Name;
                Stream albumArtStream = _playSong.Album.GetAlbumArt();
                if (albumArtStream==null)
                {
                    StreamResourceInfo albumArtPlaceholder = Application.GetResourceStream(new Uri("ApplicationIcon.png", UriKind.Relative));
                    albumArtStream = albumArtPlaceholder.Stream;
                }
                BitmapImage albumArtImage = new BitmapImage();
                albumArtImage.SetSource(albumArtStream);
                cover.Source = albumArtImage;
            }
        }

        /// <summary>
        /// 初始化按钮 
        /// </summary>
        private void setInitialButtonState() 
        {
            switch (MediaPlayer.State)
            {

                case MediaState.Playing:
                    btn_play_music.IsEnabled = false;
                    btn_stop.IsEnabled = true;
                    break;
                case MediaState.Paused:
                case MediaState.Stopped:
                    btn_play_music.IsEnabled = true;
                    btn_stop.IsEnabled = false;
                    break;
            }
        }

         
         
    }
}